@@ -3,7 +3,7 @@
 #' \code{pct.bin} implements percentile-based monotonic binning by the iterative discretization. 
 #'@param x Numeric vector to be binned.
 #'@param y Numeric target vector (binary or continuous).
-#'@param sc Numeric vector with special case elements. Default values are \code{c(NA, NaN, Inf)}.
+#'@param sc Numeric vector with special case elements. Default values are \code{c(NA, NaN, Inf, -Inf)}.
 #' Recommendation is to keep the default values always and add new ones if needed. Otherwise, if these values exist
 #' in \code{x} and are not defined in the \code{sc} list some statistics cannot be calculated properly. 
 #'@param sc.method Define how special cases will be treated, all together or in separate bins.
@@ -37,7 +37,7 @@
 #' gcd$age.d[sample(1:nrow(gcd), 3)] <- 9999999999
 #' age.d.bin <- pct.bin(x = gcd$age.d, 
 #' 			   	y = gcd$qual, 
-#' 			   	sc = c(NA, NaN, Inf, 9999999999), 
+#' 			   	sc = c(NA, NaN, Inf, -Inf, 9999999999), 
 #' 			  	sc.method = "separately",
 #' 			   	force.trend = "d")
 #' age.d.bin[[1]]
@@ -48,7 +48,7 @@
 #'@importFrom Hmisc cut2
 #'@import dplyr
 #'@export
-pct.bin <- function(x, y, sc = c(NA, NaN, Inf), sc.method = "together", g = 15, 
+pct.bin <- function(x, y, sc = c(NA, NaN, Inf, -Inf), sc.method = "together", g = 15, 
 			  y.type = NA, woe.trend = TRUE, force.trend = NA) {
 	ops <- options(scipen = 20)
 	on.exit(options(ops)) 
